# Changelog

## Version v0.4.0 (development)

- use editslots API
- remove None entries in json exports
- set default content for header and footer slot
- improve docs
- update examples

## Version v0.3.0 (development)

- add local slot edit feature


## Version v0.2.0 (development)

- rename OSL to OSW
- add page package feature


## Version v0.1.0 (development)

- create package
